@@ -1,4 +1,4 @@
-all.union <- function(sets, pow2) {
+allUnion <- function(sets, pow2) {
     if (! is.list(sets))
         stop("argument must be list")
     if (! all(sapply(sets, storage.mode) == "integer"))
