@@ -17,6 +17,10 @@
 #include <time.h>
 #include <math.h>
 #include <string.h>
+/* modifications by Geyer: really unsure whether or not die should be called
+ * below, but also unsure it shouldn't.  Better safe than sorry.
+ */
+#include "die.h"
 
 void dd_CheckAdjacency(dd_ConePtr cone,
     dd_RayPtr *RP1, dd_RayPtr *RP2, dd_boolean *adjacent)
@@ -41,10 +45,12 @@ void dd_CheckAdjacency(dd_ConePtr cone,
   set_int(Face, Face1, cone->AddedHalfspaces);
   if (set_card(Face)< cone->d - 2) {
     *adjacent = dd_FALSE;
+#ifdef R_HAS_JUMPED_THE_SHARK
     if (localdebug) {
       fprintf(stderr,"non adjacent: set_card(face) %ld < %ld = cone->d.\n",
         set_card(Face),cone->d);
     }
+#endif /* R_HAS_JUMPED_THE_SHARK */
     return;
   }
   else if (cone->parent->NondegAssumed) {
@@ -135,27 +141,35 @@ void dd_StoreRay1(dd_ConePtr cone, mytype *p, dd_boolean *feasible)
   for (i = 1; i <= cone->m; i++) {
     k=cone->OrderVector[i];
     dd_AValue(&temp, cone->d, cone->A, p, k);
+#ifdef R_HAS_JUMPED_THE_SHARK
     if (localdebug) {
       fprintf(stderr,"dd_StoreRay1: dd_AValue at row %ld =",k);
       dd_WriteNumber(stderr, temp);
       fprintf(stderr,"\n");
     }
+#endif /* R_HAS_JUMPED_THE_SHARK */
     if (dd_EqualToZero(temp)) {
       set_addelem(RR->ZeroSet, k);
+#ifdef R_HAS_JUMPED_THE_SHARK
       if (localdebug) {
         fprintf(stderr,"recognized zero!\n");
       }
+#endif /* R_HAS_JUMPED_THE_SHARK */
     }
     if (dd_Negative(temp)){
+#ifdef R_HAS_JUMPED_THE_SHARK
       if (localdebug) {
         fprintf(stderr,"recognized negative!\n");
       }
+#endif /* R_HAS_JUMPED_THE_SHARK */
       *feasible = dd_FALSE;
       if (fii>cone->m) fii=i;  /* the first violating inequality index */
+#ifdef R_HAS_JUMPED_THE_SHARK
       if (localdebug) {
         fprintf(stderr,"this ray is not feasible, neg comp = %ld\n", fii);
         dd_WriteNumber(stderr, temp);  fprintf(stderr,"\n");
       }
+#endif /* R_HAS_JUMPED_THE_SHARK */
     }
   }
   RR->FirstInfeasIndex=fii;
@@ -217,8 +231,10 @@ void dd_AddRay(dd_ConePtr cone, mytype *p)
     cone->FirstRay->Ray = (mytype *) calloc(cone->d, sizeof(mytype));
     for (j=0; j<cone->d; j++) dd_init(cone->FirstRay->Ray[j]);
     dd_init(cone->FirstRay->ARay);
+#ifdef R_HAS_JUMPED_THE_SHARK
     if (dd_debug)
       fprintf(stderr,"Create the first ray pointer\n");
+#endif /* R_HAS_JUMPED_THE_SHARK */
     cone->LastRay = cone->FirstRay;
     cone->ArtificialRay->Next = cone->FirstRay;
   } else {
@@ -226,18 +242,22 @@ void dd_AddRay(dd_ConePtr cone, mytype *p)
     cone->LastRay->Next->Ray = (mytype *) calloc(cone->d, sizeof(mytype));
     for (j=0; j<cone->d; j++) dd_init(cone->LastRay->Next->Ray[j]);
     dd_init(cone->LastRay->Next->ARay);
+#ifdef R_HAS_JUMPED_THE_SHARK
     if (dd_debug) fprintf(stderr,"Create a new ray pointer\n");
+#endif /* R_HAS_JUMPED_THE_SHARK */
     cone->LastRay = cone->LastRay->Next;
   }
   cone->LastRay->Next = NULL;
   cone->RayCount++;
   cone->TotalRayCount++;
+#ifdef R_HAS_JUMPED_THE_SHARK
   if (dd_debug) {
     if (cone->TotalRayCount % 100 == 0) {
       fprintf(stderr,"*Rays (Total, Currently Active, Feasible) =%8ld%8ld%8ld\n",
 	 cone->TotalRayCount, cone->RayCount, cone->FeasibleRayCount);
     }
   }
+#endif /* R_HAS_JUMPED_THE_SHARK */
   if (cone->parent->RelaxedEnumeration){
     dd_StoreRay2(cone, p, &feasible, &weaklyfeasible);
     if (weaklyfeasible) (cone->WeaklyFeasibleRayCount)++;
@@ -261,7 +281,7 @@ void dd_AddArtificialRay(dd_ConePtr cone)
   if (cone->d<=0) d1=1; else d1=cone->d;
   dd_InitializeArow(d1, &zerovector);
   if (cone->ArtificialRay != NULL) {
-    fprintf(stderr,"Warning !!!  FirstRay in not nil.  Illegal Call\n");
+    die("Warning !!!  FirstRay in not nil.  Illegal Call\n");
     free(zerovector); /* 086 */
     return;
   }
@@ -270,7 +290,9 @@ void dd_AddArtificialRay(dd_ConePtr cone)
   for (j=0; j<d1; j++) dd_init(cone->ArtificialRay->Ray[j]);
   dd_init(cone->ArtificialRay->ARay);
 
+#ifdef R_HAS_JUMPED_THE_SHARK
   if (dd_debug) fprintf(stderr,"Create the artificial ray pointer\n");
+#endif /* R_HAS_JUMPED_THE_SHARK */
 
   cone->LastRay=cone->ArtificialRay;
   dd_StoreRay1(cone, zerovector, &feasible);  
@@ -317,21 +339,28 @@ void dd_ConditionalAddEdge(dd_ConePtr cone,
   }
   ZSmin = Rmin->ZeroSet;
   ZSmax = Rmax->ZeroSet;
+#ifdef R_HAS_JUMPED_THE_SHARK
   if (localdebug) {
     fprintf(stderr,"dd_ConditionalAddEdge: FMIN = %ld (row%ld)   FMAX=%ld\n",
       fmin, cone->OrderVector[fmin], fmax);
   }
+#endif /* R_HAS_JUMPED_THE_SHARK */
   if (fmin==fmax){
+#ifdef R_HAS_JUMPED_THE_SHARK
     if (localdebug) fprintf(stderr,"dd_ConditionalAddEdge: equal FII value-> No edge added\n");
+#endif /* R_HAS_JUMPED_THE_SHARK */
   }
   else if (set_member(cone->OrderVector[fmin],ZSmax)){
+#ifdef R_HAS_JUMPED_THE_SHARK
     if (localdebug) fprintf(stderr,"dd_ConditionalAddEdge: No strong separation -> No edge added\n");
+#endif /* R_HAS_JUMPED_THE_SHARK */
   }
   else {  /* the pair will be separated at the iteration fmin */
     lastchance=dd_TRUE;
     /* flag to check it will be the last chance to store the edge candidate */
     set_int(Face1, ZSmax, ZSmin);
     (cone->count_int)++;
+#ifdef R_HAS_JUMPED_THE_SHARK
     if (localdebug){
       fprintf(stderr,"Face: ");
       for (it=1; it<=cone->m; it++) {
@@ -340,14 +369,17 @@ void dd_ConditionalAddEdge(dd_ConePtr cone,
       }
       fprintf(stderr,"\n");
     }
+#endif /* R_HAS_JUMPED_THE_SHARK */
     for (it=cone->Iteration+1; it < fmin && lastchance; it++){
       it_row=cone->OrderVector[it];
       if (cone->parent->EqualityIndex[it_row]>=0 && set_member(it_row, Face1)){
         lastchance=dd_FALSE;
         (cone->count_int_bad)++;
+#ifdef R_HAS_JUMPED_THE_SHARK
         if (localdebug){
           fprintf(stderr,"There will be another chance iteration %ld (row %ld) to store the pair\n", it, it_row);
         }
+#endif /* R_HAS_JUMPED_THE_SHARK */
       }
     }
     if (lastchance){
@@ -355,6 +387,7 @@ void dd_ConditionalAddEdge(dd_ConePtr cone,
       (cone->count_int_good)++;
       /* adjacent checking */
       set_int(Face, Face1, cone->AddedHalfspaces);
+#ifdef R_HAS_JUMPED_THE_SHARK
       if (localdebug){
         fprintf(stderr,"Check adjacency\n");
         fprintf(stderr,"AddedHalfspaces: "); set_fwrite(stderr,cone->AddedHalfspaces);
@@ -365,6 +398,7 @@ void dd_ConditionalAddEdge(dd_ConePtr cone,
         }
         fprintf(stderr,"\n");
       }
+#endif /* R_HAS_JUMPED_THE_SHARK */
       if (set_card(Face)< cone->d - 2) {
         adjacent = dd_FALSE;
       }
@@ -377,7 +411,9 @@ void dd_ConditionalAddEdge(dd_ConePtr cone,
           if (TempRay != Ray1 && TempRay != Ray2) {
             set_int(Face1, TempRay->ZeroSet, cone->AddedHalfspaces);
             if (set_subset(Face, Face1)) {
+#ifdef R_HAS_JUMPED_THE_SHARK 
               if (localdebug) set_fwrite(stderr,Face1);
+#endif /* R_HAS_JUMPED_THE_SHARK */
               adjacent = dd_FALSE;
             }
           }
@@ -385,8 +421,10 @@ void dd_ConditionalAddEdge(dd_ConePtr cone,
         }
       }
       if (adjacent){
+#ifdef R_HAS_JUMPED_THE_SHARK
         if (localdebug) fprintf(stderr,"The pair is adjacent and the pair must be stored for iteration %ld (row%ld)\n",
           fmin, cone->OrderVector[fmin]);
+#endif /* R_HAS_JUMPED_THE_SHARK */
         NewEdge=(dd_AdjacencyPtr) malloc(sizeof *NewEdge);
         NewEdge->Ray1=Rmax;  /* save the one remains in iteration fmin in the first */
         NewEdge->Ray2=Rmin;  /* save the one deleted in iteration fmin in the second */
@@ -395,7 +433,9 @@ void dd_ConditionalAddEdge(dd_ConePtr cone,
         (cone->TotalEdgeCount)++;
         if (cone->Edges[fmin]==NULL){
           cone->Edges[fmin]=NewEdge;
+#ifdef R_HAS_JUMPED_THE_SHARK
           if (localdebug) fprintf(stderr,"Create a new edge list of %ld\n", fmin);
+#endif /* R_HAS_JUMPED_THE_SHARK */
         }else{
           NewEdge->Next=cone->Edges[fmin];
           cone->Edges[fmin]=NewEdge;
@@ -424,7 +464,9 @@ void dd_CreateInitialEdges(dd_ConePtr cone)
     while(Ptr2!=NULL){
       fii2=Ptr2->FirstInfeasIndex;
       count++;
+#ifdef R_HAS_JUMPED_THE_SHARK
       if (localdebug) fprintf(stderr,"dd_ CreateInitialEdges: edge %ld \n",count);
+#endif /* R_HAS_JUMPED_THE_SHARK */
       dd_CheckAdjacency(cone, &Ptr1, &Ptr2, &adj);
       if (fii1!=fii2 && adj) 
         dd_ConditionalAddEdge(cone, Ptr1, Ptr2, cone->FirstRay);
@@ -451,7 +493,7 @@ void dd_UpdateEdges(dd_ConePtr cone, dd_RayPtr RRbegin, dd_RayPtr RRend)
   totalpairs=(cone->ZeroRayCount-1.0)*(cone->ZeroRayCount-2.0)+1.0;
   Ptr2begin = NULL; 
   if (RRbegin ==NULL || RRend==NULL){
-    if (1) fprintf(stderr,"Warning: dd_UpdateEdges called with NULL pointer(s)\n");
+    die("Warning: dd_UpdateEdges called with NULL pointer(s)\n");
     goto _L99;
   }
   Ptr1=RRbegin;
@@ -472,7 +514,9 @@ void dd_UpdateEdges(dd_ConePtr cone, dd_RayPtr RRbegin, dd_RayPtr RRend)
       quit=dd_FALSE;
       for (Ptr2=Ptr2begin; !quit ; Ptr2=Ptr2->Next){
         count++;
+#ifdef R_HAS_JUMPED_THE_SHARK
         if (localdebug) fprintf(stderr,"dd_UpdateEdges: edge %ld \n",count);
+#endif /* R_HAS_JUMPED_THE_SHARK */
         dd_ConditionalAddEdge(cone, Ptr1,Ptr2,RRbegin);
         if (Ptr2==RRend || Ptr2->Next==NULL) quit=dd_TRUE;
       }
@@ -480,11 +524,13 @@ void dd_UpdateEdges(dd_ConePtr cone, dd_RayPtr RRbegin, dd_RayPtr RRend)
     Ptr1=Ptr1->Next;
     pos1++;
     workleft = 100.0 * (cone->ZeroRayCount-pos1) * (cone->ZeroRayCount - pos1-1.0) / totalpairs;
+#ifdef R_HAS_JUMPED_THE_SHARK
     if (cone->ZeroRayCount>=500 && dd_debug && pos1%10 ==0 && prevworkleft-workleft>=10 ) {
       fprintf(stderr,"*Work of iteration %5ld(/%ld): %4ld/%4ld => %4.1f%% left\n",
 	     cone->Iteration, cone->m, pos1, cone->ZeroRayCount, workleft);
       prevworkleft=workleft;
     }    
+#endif /* R_HAS_JUMPED_THE_SHARK */
   }while(Ptr1!=RRend && Ptr1!=NULL);
 _L99:;  
 }
@@ -525,7 +571,9 @@ dd_clear(cone->LastRay->Ray[j]);
     free(cone->LastRay);
     cone->LastRay = NULL;
     cone->ArtificialRay=NULL;
+#ifdef R_HAS_JUMPED_THE_SHARK
     if (localdebug) fprintf(stderr,"%ld ray storage spaces freed\n",count);
+#endif /* R_HAS_JUMPED_THE_SHARK */
   }
 /* must add (by Sato) */
   free(cone->Edges);
@@ -886,18 +934,22 @@ void dd_ColumnReduce(dd_ConePtr cone)
       if (j1<j) {
         for (i=1; i<=cone->m; i++) dd_set(cone->A[i-1][j1-1],cone->A[i-1][j-1]);
         cone->newcol[j]=j1;
+#ifdef R_HAS_JUMPED_THE_SHARK
         if (localdebug){
           fprintf(stderr,"shifting the column %ld to column %ld\n", j, j1);
         }
+#endif /* R_HAS_JUMPED_THE_SHARK */
           /* shifting forward */
       }
     } else {
       cone->newcol[j]=0;
+#ifdef R_HAS_JUMPED_THE_SHARK
       if (localdebug) {
         fprintf(stderr,"a generator (or an equation) of the linearity space: ");
         for (i=1; i<=cone->d; i++) dd_WriteNumber(stderr, cone->B[i-1][j-1]);
         fprintf(stderr,"\n");
       }
+#endif /* R_HAS_JUMPED_THE_SHARK */
     }
   }
   cone->d=j1;  /* update the dimension. cone->d_orig remembers the old. */
@@ -935,8 +987,10 @@ long dd_MatrixRank(dd_MatrixPtr M, dd_rowset ignoredrows, dd_colset ignoredcols,
   do {   /* Find a set of rows for a basis */
       dd_SelectPivot2(M->rowsize, M->colsize,M->matrix,B,dd_MinIndex,roworder,
        PriorityRow,M->rowsize, NopivotRow, ColSelected, &r, &s, &chosen);
+#ifdef R_HAS_JUMPED_THE_SHARK
       if (dd_debug && chosen) 
         fprintf(stderr,"Procedure dd_MatrixRank: pivot on (r,s) =(%ld, %ld).\n", r, s);
+#endif /* R_HAS_JUMPED_THE_SHARK */
       if (chosen) {
         set_addelem(NopivotRow, r);
         set_addelem(*rowbasis, r);
@@ -944,7 +998,9 @@ long dd_MatrixRank(dd_MatrixPtr M, dd_rowset ignoredrows, dd_colset ignoredcols,
         set_addelem(*colbasis, s);
         rank++;
         dd_GaussianColumnPivot(M->rowsize, M->colsize, M->matrix, B, r, s);
+#ifdef R_HAS_JUMPED_THE_SHARK
         if (localdebug) dd_WriteBmatrix(stderr,M->colsize,B);
+#endif /* R_HAS_JUMPED_THE_SHARK */
       } else {
         stop=dd_TRUE;
       }
@@ -978,8 +1034,10 @@ void dd_FindBasis(dd_ConePtr cone, long *rank)
   do {   /* Find a set of rows for a basis */
       dd_SelectPivot2(cone->m, cone->d,cone->A,cone->B,cone->HalfspaceOrder,cone->OrderVector,
        cone->EqualitySet,cone->m, NopivotRow, ColSelected, &r, &s, &chosen);
+#ifdef R_HAS_JUMPED_THE_SHARK
       if (dd_debug && chosen) 
         fprintf(stderr,"Procedure dd_FindBasis: pivot on (r,s) =(%ld, %ld).\n", r, s);
+#endif /* R_HAS_JUMPED_THE_SHARK */
       if (chosen) {
         set_addelem(cone->InitialHalfspaces, r);
         set_addelem(NopivotRow, r);
@@ -987,7 +1045,9 @@ void dd_FindBasis(dd_ConePtr cone, long *rank)
         cone->InitialRayIndex[s]=r;    /* cone->InitialRayIndex[s] stores the corr. row index */
         (*rank)++;
         dd_GaussianColumnPivot(cone->m, cone->d, cone->A, cone->B, r, s);
+#ifdef R_HAS_JUMPED_THE_SHARK
         if (localdebug) dd_WriteBmatrix(stderr,cone->d,cone->B);
+#endif /* R_HAS_JUMPED_THE_SHARK */
       } else {
         stop=dd_TRUE;
       }
@@ -1013,25 +1073,33 @@ void dd_FindInitialRays(dd_ConePtr cone, dd_boolean *found)
     cone->PreOrderedRun=dd_FALSE;
   }
   else cone->PreOrderedRun=dd_TRUE;
+#ifdef R_HAS_JUMPED_THE_SHARK
   if (dd_debug) dd_WriteBmatrix(stderr, cone->d, cone->B);
+#endif /* R_HAS_JUMPED_THE_SHARK */
   for (i = 1; i <= cone->m; i++)
     if (!set_member(i,cone->NonequalitySet)) set_addelem(CandidateRows, i);
     /*all rows not in NonequalitySet are candidates for initial cone*/
   dd_FindBasis(cone, &rank);
+#ifdef R_HAS_JUMPED_THE_SHARK
   if (dd_debug) dd_WriteBmatrix(stderr, cone->d, cone->B);
   if (dd_debug) fprintf(stderr,"dd_FindInitialRays: rank of Amatrix = %ld\n", rank);
+#endif /* R_HAS_JUMPED_THE_SHARK */
   cone->LinearityDim=cone->d - rank;
+#ifdef R_HAS_JUMPED_THE_SHARK
   if (dd_debug) fprintf(stderr,"Linearity Dimension = %ld\n", cone->LinearityDim);
+#endif /* R_HAS_JUMPED_THE_SHARK */
   if (cone->LinearityDim > 0) {
      dd_ColumnReduce(cone);
      dd_FindBasis(cone, &rank);
   }
   if (!set_subset(cone->EqualitySet,cone->InitialHalfspaces)) {
+#ifdef R_HAS_JUMPED_THE_SHARK
     if (dd_debug) {
       fprintf(stderr,"Equality set is dependent. Equality Set and an initial basis:\n");
       set_fwrite(stderr,cone->EqualitySet);
       set_fwrite(stderr,cone->InitialHalfspaces);
     };
+#endif /* R_HAS_JUMPED_THE_SHARK */
   }
   *found = dd_TRUE;
   set_free(CandidateRows);
@@ -1049,8 +1117,10 @@ void dd_CheckEquality(dd_colrange d_size, dd_RayPtr*RP1, dd_RayPtr*RP2, dd_boole
 {
   long j;
 
+#ifdef R_HAS_JUMPED_THE_SHARK
   if (dd_debug)
     fprintf(stderr,"Check equality of two rays\n");
+#endif /* R_HAS_JUMPED_THE_SHARK */
   *equal = dd_TRUE;
   j = 1;
   while (j <= d_size && *equal) {
@@ -1059,7 +1129,7 @@ void dd_CheckEquality(dd_colrange d_size, dd_RayPtr*RP1, dd_RayPtr*RP2, dd_boole
     j++;
   }
   if (*equal)
-    fprintf(stderr,"Equal records found !!!!\n");
+    die("Equal records found !!!!\n");
 }
 
 void dd_CreateNewRay(dd_ConePtr cone, 
@@ -1085,26 +1155,34 @@ void dd_CreateNewRay(dd_ConePtr cone,
 
   dd_AValue(&a1, cone->d, cone->A, Ptr1->Ray, ii);
   dd_AValue(&a2, cone->d, cone->A, Ptr2->Ray, ii);
+#ifdef R_HAS_JUMPED_THE_SHARK
   if (localdebug) {
     fprintf(stderr,"CreatNewRay: Ray1 ="); dd_WriteArow(stderr, Ptr1->Ray, cone->d);
     fprintf(stderr,"CreatNewRay: Ray2 ="); dd_WriteArow(stderr, Ptr2->Ray, cone->d);
   }
+#endif /* R_HAS_JUMPED_THE_SHARK */
   dd_abs(v1,a1);
   dd_abs(v2,a2);
+#ifdef R_HAS_JUMPED_THE_SHARK
   if (localdebug){
     fprintf(stderr,"dd_AValue1 and ABS");  dd_WriteNumber(stderr,a1); dd_WriteNumber(stderr,v1); fprintf(stderr,"\n");
     fprintf(stderr,"dd_AValue2 and ABS");  dd_WriteNumber(stderr,a2); dd_WriteNumber(stderr,v2); fprintf(stderr,"\n");
   }
+#endif /* R_HAS_JUMPED_THE_SHARK */
   for (j = 0; j < cone->d; j++){
     dd_LinearComb(NewRay[j], Ptr1->Ray[j],v2,Ptr2->Ray[j],v1);
   }
+#ifdef R_HAS_JUMPED_THE_SHARK
   if (localdebug) {
     fprintf(stderr,"CreatNewRay: New ray ="); dd_WriteArow(stderr, NewRay, cone->d);
   }
+#endif /* R_HAS_JUMPED_THE_SHARK */
   dd_Normalize(cone->d, NewRay);
+#ifdef R_HAS_JUMPED_THE_SHARK
   if (localdebug) {
     fprintf(stderr,"CreatNewRay: dd_Normalized ray ="); dd_WriteArow(stderr, NewRay, cone->d);
   }
+#endif /* R_HAS_JUMPED_THE_SHARK */
   dd_AddRay(cone, NewRay);
   dd_clear(a1); dd_clear(a2); dd_clear(v1); dd_clear(v2);
 }
@@ -1124,7 +1202,7 @@ void dd_EvaluateARay1(dd_rowrange i, dd_ConePtr cone)
   Ptr = cone->FirstRay;
   PrevPtr = cone->ArtificialRay;
   if (PrevPtr->Next != Ptr) {
-    fprintf(stderr,"Error.  Artificial Ray does not point to FirstRay!!!\n");
+    die("Error.  Artificial Ray does not point to FirstRay!!!\n");
   }
   while (Ptr != NULL) {
     dd_set(temp,dd_purezero);
@@ -1280,7 +1358,7 @@ void dd_DeleteNegativeRays(dd_ConePtr cone)
   PrevPtr= cone->ArtificialRay;
   Ptr = cone->FirstRay;
   if (PrevPtr->Next != Ptr) 
-    fprintf(stderr,"Error at dd_DeleteNegativeRays: ArtificialRay does not point the FirstRay.\n");
+    die("Error at dd_DeleteNegativeRays: ArtificialRay does not point the FirstRay.\n");
   completed=dd_FALSE;
   while (Ptr != NULL && !completed){
 /*    if ( (Ptr->ARay) < -zero ){ */
@@ -1299,11 +1377,13 @@ void dd_DeleteNegativeRays(dd_ConePtr cone)
   while (Ptr != NULL) {
     NextPtr=Ptr->Next;  /* remember the Next record */
     dd_set(temp,Ptr->ARay);
+#ifdef R_HAS_JUMPED_THE_SHARK
     if (localdebug) {fprintf(stderr,"Ptr->ARay :"); dd_WriteNumber(stderr, temp);}
+#endif /* R_HAS_JUMPED_THE_SHARK */
 /*    if ( temp < -zero) {*/
     if ( dd_Negative(temp)) {
       if (!negfound){
-        fprintf(stderr,"Error: An infeasible ray found after their removal\n");
+        die("Error: An infeasible ray found after their removal\n");
         negfound=dd_TRUE;
       }
     }
@@ -1523,11 +1603,13 @@ void dd_AddNewHalfspace1(dd_ConePtr cone, dd_rowrange hnew)
     }
     pos1++;
     progress = 100.0 * ((double)pos1 / pos2) * (2.0 * pos2 - pos1) / pos2;
+#ifdef R_HAS_JUMPED_THE_SHARK
     if (progress-prevprogress>=10 && pos1%10==0 && dd_debug) {
       fprintf(stderr,"*Progress of iteration %5ld(/%ld):   %4ld/%4ld => %4.1f%% done\n",
 	     cone->Iteration, cone->m, pos1, pos2, progress);
       prevprogress=progress;
     }
+#endif /* R_HAS_JUMPED_THE_SHARK */
   }
   if (cone->RayCount==cone->WeaklyFeasibleRayCount) cone->CompStatus=dd_AllFound;
   _L99:;
@@ -1555,6 +1637,7 @@ void dd_AddNewHalfspace2(dd_ConePtr cone, dd_rowrange hnew)
     goto _L99;   /* All rays are infeasible, and the computation must stop */
   }
   
+#ifdef R_HAS_JUMPED_THE_SHARK
   if (localdebug){
     pos1=0;
     fprintf(stderr,"(pos, FirstInfeasIndex, A Ray)=\n");
@@ -1566,6 +1649,7 @@ void dd_AddNewHalfspace2(dd_ConePtr cone, dd_rowrange hnew)
    }
     fprintf(stderr,"\n");
   }
+#endif /* R_HAS_JUMPED_THE_SHARK */
   
   if (cone->ZeroHead==NULL) cone->ZeroHead=cone->LastRay;
 
@@ -1591,7 +1675,9 @@ void dd_AddNewHalfspace2(dd_ConePtr cone, dd_rowrange hnew)
 
   if (cone->Iteration<cone->m){
     if (cone->ZeroHead!=NULL && cone->ZeroHead!=cone->LastRay){
+#ifdef R_HAS_JUMPED_THE_SHARK
       if (cone->ZeroRayCount>200 && dd_debug) fprintf(stderr,"*New edges being scanned...\n");
+#endif /* R_HAS_JUMPED_THE_SHARK */
       dd_UpdateEdges(cone, cone->ZeroHead, cone->LastRay);
     }
   }
@@ -1657,9 +1743,11 @@ void dd_SelectNextHalfspace2(dd_ConePtr cone, dd_rowset excluded, dd_rowrange *h
       }
     }
   }
+#ifdef R_HAS_JUMPED_THE_SHARK
   if (dd_debug) {
     fprintf(stderr,"*infeasible rays (min) =%5ld, #feas rays =%5ld\n", infmin, fi);
   }
+#endif /* R_HAS_JUMPED_THE_SHARK */
 }
 
 void dd_SelectNextHalfspace3(dd_ConePtr cone, dd_rowset excluded, dd_rowrange *hnext)
@@ -1679,9 +1767,11 @@ void dd_SelectNextHalfspace3(dd_ConePtr cone, dd_rowset excluded, dd_rowrange *h
       }
     }
   }
+#ifdef R_HAS_JUMPED_THE_SHARK
   if (localdebug) {
     fprintf(stderr,"*infeasible rays (max) =%5ld, #feas rays =%5ld\n", infmax, fi);
   }
+#endif /* R_HAS_JUMPED_THE_SHARK */
 }
 
 void dd_SelectNextHalfspace4(dd_ConePtr cone, dd_rowset excluded, dd_rowrange *hnext)
@@ -1708,11 +1798,13 @@ void dd_SelectNextHalfspace4(dd_ConePtr cone, dd_rowset excluded, dd_rowrange *h
   }
   if (!dd_debug)
     return;
+#ifdef R_HAS_JUMPED_THE_SHARK
   if (max == fi) {
     fprintf(stderr,"*infeasible rays (min) =%5ld, #feas rays =%5ld\n", infi, fi);
   } else {
     fprintf(stderr,"*infeasible rays (max) =%5ld, #feas rays =%5ld\n", infi, fi);
   }
+#endif /* R_HAS_JUMPED_THE_SHARK */
 }
 
 void dd_SelectNextHalfspace5(dd_ConePtr cone, dd_rowset excluded, dd_rowrange *hnext)
@@ -1800,6 +1892,7 @@ void dd_UniqueRows(dd_rowindex OV, long p, long r, dd_Amatrix A, long dmax, dd_r
     }
   }
   *uniqrows=j;
+#ifdef R_HAS_JUMPED_THE_SHARK
   if (localdebug){
     printf("The number of unique rows are %ld\n with order vector",*uniqrows);
     for (i=p;i<=r; i++){
@@ -1807,6 +1900,7 @@ void dd_UniqueRows(dd_rowindex OV, long p, long r, dd_Amatrix A, long dmax, dd_r
     }
     printf("\n");
   }
+#endif /* R_HAS_JUMPED_THE_SHARK */
   _L99:;
 }
 
@@ -1865,11 +1959,15 @@ void dd_RandomPermutation(dd_rowindex OV, long t, unsigned int seed)
     u=r/rand_max;
     xk=(double)(j*u +1);
     k=(long)xk;
+#ifdef R_HAS_JUMPED_THE_SHARK
     if (localdebug) fprintf(stderr,"u=%g, k=%ld, r=%g, randmax= %g\n",u,k,r,rand_max);
+#endif /* R_HAS_JUMPED_THE_SHARK */
     ovj=OV[j];
     OV[j]=OV[k];
     OV[k]=ovj;
+#ifdef R_HAS_JUMPED_THE_SHARK
     if (localdebug) fprintf(stderr,"row %ld is exchanged with %ld\n",j,k); 
+#endif /* R_HAS_JUMPED_THE_SHARK */
   }
 }
 
@@ -1924,14 +2022,18 @@ in highest order.
   if (dd_debug) localdebug=dd_TRUE;
   found=dd_TRUE;
   rr=set_card(PriorityRows);
+#ifdef R_HAS_JUMPED_THE_SHARK
   if (localdebug) set_fwrite(stderr,PriorityRows);
+#endif /* R_HAS_JUMPED_THE_SHARK */
   for (i=1; i<=rr; i++){
     found=dd_FALSE;
     for (j=i; j<=cone->m && !found; j++){
       oj=cone->OrderVector[j];
       if (set_member(oj, PriorityRows)){
         found=dd_TRUE;
+#ifdef R_HAS_JUMPED_THE_SHARK
         if (localdebug) fprintf(stderr,"%ldth in sorted list (row %ld) is in PriorityRows\n", j, oj);
+#endif /* R_HAS_JUMPED_THE_SHARK */
         j1=j;
       }
     }
@@ -1940,14 +2042,16 @@ in highest order.
         /* shift everything lower: ov[i]->cone->ov[i+1]..ov[j1-1]->cone->ov[j1] */
         for (k=j1; k>=i; k--) cone->OrderVector[k]=cone->OrderVector[k-1];
         cone->OrderVector[i]=oj;
+#ifdef R_HAS_JUMPED_THE_SHARK
         if (localdebug){
           fprintf(stderr,"OrderVector updated to:\n");
           for (j = 1; j <= cone->m; j++) fprintf(stderr," %2ld", cone->OrderVector[j]);
           fprintf(stderr,"\n");
         }
+#endif /* R_HAS_JUMPED_THE_SHARK */
       }
     } else {
-      fprintf(stderr,"UpdateRowOrder: Error.\n");
+      die("UpdateRowOrder: Error.\n");
       goto _L99;
     }
   }
@@ -1968,15 +2072,19 @@ void dd_SelectPreorderedNext(dd_ConePtr cone, dd_rowset excluded, dd_rowrange *h
 void dd_SelectNextHalfspace(dd_ConePtr cone, dd_rowset excluded, dd_rowrange *hh)
 {
   if (cone->PreOrderedRun){
+#ifdef R_HAS_JUMPED_THE_SHARK
     if (dd_debug) {
       fprintf(stderr,"debug dd_SelectNextHalfspace: Use PreorderNext\n");
     }
+#endif /* R_HAS_JUMPED_THE_SHARK */
     dd_SelectPreorderedNext(cone, excluded, hh);
   }
   else {
+#ifdef R_HAS_JUMPED_THE_SHARK
     if (dd_debug) {
       fprintf(stderr,"debug dd_SelectNextHalfspace: Use DynamicOrderedNext\n");
     }
+#endif /* R_HAS_JUMPED_THE_SHARK */
 
     switch (cone->HalfspaceOrder) {
 
@@ -2093,6 +2201,7 @@ void dd_InnerProduct(mytype prod, dd_colrange d, dd_Arow v1, dd_Arow v2)
     dd_mul(temp,v1[j],v2[j]); 
     dd_add(prod,prod,temp);
   }
+#ifdef R_HAS_JUMPED_THE_SHARK
   if (localdebug) {
     fprintf(stderr,"InnerProduct:\n"); 
     dd_WriteArow(stderr, v1, d);
@@ -2101,6 +2210,7 @@ void dd_InnerProduct(mytype prod, dd_colrange d, dd_Arow v1, dd_Arow v2)
     dd_WriteNumber(stderr, prod);
     fprintf(stderr,"\n");
   }
+#endif /* R_HAS_JUMPED_THE_SHARK */
   
   dd_clear(temp);
 }
